@@ -4,6 +4,7 @@ from datetime import datetime
 import os
 import re
 from glob import glob
+import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib.cm as cm
 import matplotlib.colors as colors
@@ -11,7 +12,6 @@ from matplotlib.patches import Rectangle
 import matplotlib.transforms as transforms
 from matplotlib.collections import LineCollection
 from mpl_toolkits.axes_grid1 import make_axes_locatable
-import numpy as np
 import warnings
 from . import axonaIO
 from .tetrode_dict import TetrodeDict
@@ -182,12 +182,12 @@ class Trial(axonaIO.IO, SAC, dict):
 		filename : str
 			The absolute path the files being analysed here without any suffix
 		'''
-
-		pname, fname = os.path.split(filename)
-		if len(pname) == 0:
-			defaultDir = r'/home/robin/Dropbox/Science/Recordings'
-			animal = filename.split('_')[0]
-			filename = os.path.join(defaultDir, animal, filename)
+		if os.path.isdir(r'/home/robin/Dropbox/Science/Recordings'):
+			pname, fname = os.path.split(filename)
+			if len(pname) == 0:
+				defaultDir = r'/home/robin/Dropbox/Science/Recordings'
+				animal = filename.split('_')[0]
+				filename = os.path.join(defaultDir, animal, filename)
 		return filename
 
 	@property
@@ -2683,8 +2683,6 @@ class Trial(axonaIO.IO, SAC, dict):
 		ax7 = axes[2][1] # bottom-middle
 		ax8 = axes[2][2] # bottom-right
 
-		axes_idx = range(9)
-		axes_idx.remove(4)
 		max_rate = 0
 		for d in zip(dirs_st, dirs_en):
 			self.posFilter = {'dir': (d[0], d[1])}
