@@ -1,5 +1,5 @@
-from . import axonaIO
-import dacq2py
+from ephysiopy.dacq2py import axonaIO
+
 class TetrodeDict(dict):
 	def __init__(self, filename_root, *args, **kwargs):
 		self.filename_root = filename_root
@@ -9,11 +9,11 @@ class TetrodeDict(dict):
 			self._volts = kwargs['volts']
 		else:
 			self._volts = True
-		
+
 	def update(self, *args, **kwargs):
 		for k, v in dict(*args, **kwargs).items():
 			self[k] = v
-			
+
 	def __getitem__(self, key):
 		if isinstance(key, int):
 			try:
@@ -22,11 +22,8 @@ class TetrodeDict(dict):
 			except KeyError:
 				if key in self.valid_keys:
 					try:
-						val = dacq2py.axonaIO.Tetrode(self.filename_root, key, self._volts)
-						self.__setitem__(key, val)
+						val = axonaIO.Tetrode(self.filename_root, key, self._volts)
+						self[key] = val
 						return val
 					except IOError:
-						print("IOError for file {} on tetrode {}".format(self.filename_root, key))
-						
-	def __setitem__(self, key, val):
-		dict.__setitem__(self, key, val)
\ No newline at end of file
+						print("IOError for file {} on tetrode {}".format(self.filename_root, key))
\ No newline at end of file
