@@ -178,7 +178,7 @@ class SpikeCalcsGeneric(object):
         '''
         Plots all scorrs in a single figure window
         '''
-        from dacq2py import spikecalcs
+        from ephysiopy.dacq2py import spikecalcs
         SpkCalcs = spikecalcs.SpikeCalcs()
         if fig is None:
             fig = plt.figure(figsize=(10,20))
@@ -392,8 +392,9 @@ class PosCalcsGeneric(object):
         else:
             self.sample_rate = 30
 
+        xy = xy.astype(np.int32)
         xy = self.speedfilter(xy)
-        xy = self.interpnans(xy)
+        # xy = self.interpnans(xy) # ADJUST THIS SO NP.MASKED ARE INTERPOLATED OVER
         xy = self.smoothPos(xy)
         self.calcSpeed(xy)
 
@@ -409,14 +410,14 @@ class PosCalcsGeneric(object):
 
     def speedfilter(self, xy):
         maxppmsqd = self.jumpmax ** 2
-        df = np.diff(xy)
-        disp = np.hypot(df[0,:], df[1,:])
+        df = np.diff(xy, axis=0)
+        disp = np.hypot(df[:,0], df[:,1])
         disp = np.insert(disp, -1, 0)
-        xy[:, disp > maxppmsqd] = np.ma.masked
+        xy[disp > maxppmsqd, :] = np.ma.masked
         return xy
 
     def interpnans(self, xy):
-        for i in range(0,len(xy), 2):
+        for i in range(0,np.shape(xy)[-1]):
             missing = xy[i:i+2].mask.any(axis=0)
             ok = np.logical_not(missing)
             ok_idx = np.nonzero(np.ravel(ok))[0]#gets the indices of ok poses
@@ -426,7 +427,7 @@ class PosCalcsGeneric(object):
             xy.data[i,missing_idx] = np.interp(missing_idx,ok_idx,good_data)#,left=np.min(good_data),right=np.max(good_data)
             xy.data[i+1,missing_idx] = np.interp(missing_idx,ok_idx,good_data1)
         xy.mask = 0
-        print("{} bad/ jumpy positions were interpolated over".format(len(missing_idx)))
+        print("{} bad/ jumpy positions were interpolated over".format(len(missing_idx)))#this is wrong i think
         return xy
 
     def smoothPos(self, xy):
@@ -439,7 +440,7 @@ class PosCalcsGeneric(object):
         x = xy[0].astype(np.float64)
         y = xy[1].astype(np.float64)
 
-        from dacq2py import smoothdata
+        from ephysiopy.dacq2py import smoothdata
         # TODO: calculate window_len from pos sampling rate
         # 11 is roughly equal to 400ms at 30Hz (window_len needs to be odd)
         sm_x = smoothdata.smooth(x, window_len=11, window='flat')
@@ -542,7 +543,7 @@ class MapCalcsGeneric(object):
             else:
                 fig = plt.figure(figsize=(20,10))#, constrained_layout=True)
         if 'sac' in what_to_plot:
-            from dacq2py import gridcell
+            from ephysiopy.dacq2py import gridcell
             S = gridcell.SAC()
             print(gridcell.__file__)
         import matplotlib.gridspec as gridspec
@@ -558,35 +559,35 @@ class MapCalcsGeneric(object):
         for i, cluster in enumerate(self.good_clusters):
             inner = gridspec.GridSpecFromSubplotSpec(inner_nrows,inner_ncols, subplot_spec=outer[i])
             for plot_type_idx, plot_type in enumerate(what_to_plot):
-                if 'path' in plot_type:
-                    ax = fig.add_subplot(inner[plot_type_idx])
-                    self.makeSpikePathPlot(cluster, ax)
-                if 'map' in plot_type:
-                    ax = fig.add_subplot(inner[plot_type_idx])
-                    rmap = self.makeRateMap(cluster, ax)
                 if 'hdir' in plot_type:
                     ax = fig.add_subplot(inner[plot_type_idx],projection='polar')
+                else:
+                    ax = fig.add_subplot(inner[plot_type_idx])
+
+                if 'path' in plot_type:
+                    self.makeSpikePathPlot(cluster, ax)
+                if 'map' in plot_type:
+                    rmap = self.makeRateMap(cluster, ax)
+                if 'hdir' in plot_type:
                     self.makeHDPlot(cluster, ax, add_mrv=True)
                 if 'sac' in plot_type:
-                    ax = fig.add_subplot(inner[plot_type_idx])
                     rmap = self.makeRateMap(cluster)
                     nodwell = ~np.isfinite(rmap[0])
                     sac = S.autoCorr2D(rmap[0], nodwell)
                     d = S.getMeasures(sac)
                     S.show(sac,d,ax)
                 if 'speed' in plot_type:
-                    ax = fig.add_subplot(inner[plot_type_idx])
                     self.makeSpeedVsRatePlot(cluster, 0.0, 40.0, 3.0, ax)
                 if 'sp_hd' in plot_type:
-                    ax = fig.add_subplot(inner[plot_type_idx])
                     self.makeSpeedVsHeadDirectionPlot(cluster, ax)
-                if first_sub_axis in plot_type: # label the first sub-axis only
-                    ax.set_title(cluster, fontweight='bold', size=8)
+                # if first_sub_axis in plot_type: # label the first sub-axis only
+                    # ax = fig.add_subplot(inner[plot_type_idx])
+                ax.set_title(cluster, fontweight='bold', size=8)
         plt.show()
 
     def __iter__(self):
         if 'all' in self.plot_type:
-            from dacq2py import gridcell
+            from ephysiopy.dacq2py import gridcell
             S = gridcell.SAC()
 
         for cluster in self.good_clusters:
@@ -702,7 +703,7 @@ class MapCalcsGeneric(object):
 
             # See if we should add the mean resultant vector (mrv)
             if 'add_mrv' in kwargs.keys():
-                from dacq2py import statscalcs
+                from ephysiopy.dacq2py import statscalcs
                 S = statscalcs.StatsCalcs()
                 angles = self.hdir[self.spk_pos_idx[self.spk_clusters==cluster]]
                 r, th = S.mean_resultant_vector(np.deg2rad(angles))
@@ -726,7 +727,7 @@ class MapCalcsGeneric(object):
         speed_filt = np.ma.MaskedArray(speed)
         speed_filt = np.ma.masked_where(speed_filt < minSpeed, speed_filt)
         speed_filt = np.ma.masked_where(speed_filt > maxSpeed, speed_filt)
-        from dacq2py import spikecalcs
+        from ephysiopy.dacq2py import spikecalcs
         S = spikecalcs.SpikeCalcs();
         x1 = self.spk_pos_idx[self.spk_clusters==cluster]
         spk_sm = S.smoothSpikePosCount(x1, self.pos_ts.shape[0], sigma, None)
