@@ -15,9 +15,9 @@ except ImportError:
 from collections import OrderedDict
 
 try:
-    from .epy.openephys2py.OESettings import Settings
+    from .ephysiopy.openephys2py.OESettings import Settings
 except ImportError:
-    from epy.openephys2py.OESettings import Settings
+    from ephysiopy.openephys2py.OESettings import Settings
 '''
 The results of a kilosort session are a load of .npy files, a .csv file
 and some other stuff
@@ -40,7 +40,16 @@ class KiloSortSession(object):
 
     '''
     def __init__(self, fname_root):
+        '''
+        Walk through the path to find the location of the files in case this has been
+        called in another way i.e. binary format a la Neuropixels
+        '''
         self.fname_root = fname_root
+        import os
+        for d, c, f in os.walk(fname_root):
+            for ff in f:
+                if 'spike_times.npy' in ff:
+                    self.fname_root = d
         self.cluster_id = None
         self.spk_clusters = None
         self.spk_times = None
@@ -68,169 +77,62 @@ class KiloSortSession(object):
                 if 'noise' not in id_group[1].decode():
                     self.good_clusters.append(id_group[0])
 
-class OpenEphysNWB(object):
-    '''
-    Parameters
-    ------------
-    fname_root:- str
-        Should contain the settings.xml file and the .nwb file
-    '''
 
-    def __init__(self, fname_root, **kwargs):
-        self.fname_root = fname_root # str
-        self.kilodata = None # a KiloSortSession object - see class above
-        self.nwbData = None # handle to the open nwb file (HDF5 file object)
-        self.rawData = None # np.array holding the raw, continuous recording
+class OpenEphysBase(object):
+    """
+    Base class for openephys anaylsis with data recorded in either the NWB or binary format
+    """
+    def __init__(self, pname_root, **kwargs):
+        super().__init__()
+        self.pname_root = pname_root # top-level directory, typically of form YYYY-MM-DD_HH-MM-SS
+        self.settings = None
+        self.kilodata = None
+        self.rawData = None
+        self.xy = None
+        self.xyTS = None
+        self.ts = None
+        self.ttl_data = None
+        self.ttl_timestamps = None
         self.spikeData = None # a list of np.arrays, nominally containing tetrode data in format nspikes x 4 x 40
         self.accelerometerData = None # np.array
-        self.timeAligned = False # deprecated
-        self.mapiter = None # iterator plotting rate maps etc
         self.settings = None # OESettings.Settings instance
-        self.recording_name = None # the recording name inside the nwb file ('recording0', 'recording1', etc)
         if ('jumpmax' in kwargs.keys()):
             self.jumpmax = kwargs['jumpmax']
         else:
             self.jumpmax = 100
 
-    def load(self, session_name=None, recording_name=None, loadraw=False, loadspikes=False, savedat=False):
-        '''
-        Loads xy pos from binary part of the hdf5 file and data resulting from
-        a Kilosort session (see KiloSortSession class above)
-
-        Parameters
-        ----------
-        session_name : str
-            Defaults to experiment_1.nwb
-        recording_name : str
-            Defaults to recording0
-        loadraw : bool
-            Defaults to False; if True will load and save the
-            raw part of the data
-        savedat : bool
-            Defaults to False; if True will extract the electrode
-            data part of the hdf file and save as 'experiment_1.dat'
-            NB only works if loadraw is True. Also note that this
-            currently saves 64 channels worth of data (ie ignores
-            the 6 accelerometer channels)
-        '''
-
-        import h5py
-        import os
-        if session_name is None:
-            session_name = 'experiment_1.nwb'
-        self.nwbData = h5py.File(os.path.join(self.fname_root, session_name))
-        # Position data...
-        if self.recording_name is None:
-            if recording_name is None:
-                recording_name = 'recording0'
-            self.recording_name = recording_name
-        self.xy = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['data'])
-
-        self.xyTS = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['timestamps'])
-        self.xyTS = self.xyTS - (self.xy[:,2] / 1e6)
-        self.xy = self.xy[:,0:2]
-        # TTL data...
-        self.ttl_data = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['ttl1']['data'])
-        self.ttl_timestamps = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['ttl1']['timestamps'])
-
-        # ...everything else
-        try:
-            settings = Settings(os.path.join(self.fname_root, 'settings.xml'))
-            settings.load()
-            settings.parse()
-            self.settings = settings
-            fpgaId = settings.fpga_nodeId
-            fpgaNode = 'processor' + str(fpgaId) + '_' + str(fpgaId)
-            self.ts = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['continuous'][fpgaNode]['timestamps'])
-            if (loadraw == True):
-                self.rawData = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['continuous'][fpgaNode]['data'])
-                settings.parseChannels() # to get the neural data channels
-                self.accelerometerData = self.rawData[:,64:]
-                self.rawData = self.rawData[:,0:64]
-                if (savedat == True):
-                    data2save = self.rawData[:,0:64]
-                    data2save.tofile(os.path.join(self.fname_root, 'experiment_1.dat'))
-            if loadspikes == True:
-                if self.nwbData['acquisition']['timeseries'][self.recording_name]['spikes']:
-                    # Create a dictionary containing keys 'electrode1', 'electrode2' etc and None for values
-                    electrode_dict = dict.fromkeys(self.nwbData['acquisition']['timeseries'][self.recording_name]['spikes'].keys())
-                    # Each entry in the electrode dict is itself a dict containing keys 'timestamps' and 'data'...
-                    for i_electrode in electrode_dict.keys():
-                        data_and_ts_dict = {'timestamps': None, 'data': None}
-                        data_and_ts_dict['timestamps'] = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['spikes'][i_electrode]['timestamps'])
-                        data_and_ts_dict['data'] = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['spikes'][i_electrode]['data'])
-                        electrode_dict[i_electrode] = data_and_ts_dict
-            self.spikeData = electrode_dict
-        except:
-            self.ts = self.xy
-
-    def save_ttl(self, out_fname):
-        '''
-        Saves the ttl data to text file out_fname
-        '''
-        import numpy as np
-        if ( len(self.ttl_data) > 0 ) and ( len(self.ttl_timestamps) > 0 ):
-            data = np.array([self.ttl_data, self.ttl_timestamps])
-            if data.shape[0] == 2:
-                data = data.T
-            np.savetxt(out_fname, data, delimiter='\t')
-
-    def exportPos(self):
-        xy = self.plotPos(show=False)
-        out = np.hstack([xy.T, self.xyTS[:,np.newaxis]])
-        np.savetxt('position.txt', out, delimiter=',', fmt=['%3.3i','%3.3i','%3.3f'])
-
     def loadKilo(self):
         '''
         Loads a kilosort session
         '''
-        kilodata = KiloSortSession(self.fname_root)
+        kilodata = KiloSortSession(self.pname_root) # pname_root gets walked through and over-written with correct location of kiolsort data
         kilodata.load()
         kilodata.removeNoiseClusters()
         self.kilodata = kilodata
 
-    def __alignTimeStamps__(self):
+    def __loadSettings__(self):
         '''
-        For some reason the timestamps of the data in self.xyTS and self.ts start
-        at some positive, non-zero value (timestamps might 'start' when the Play
-        button is pressed as opposed to the Record button in openephys). Also
-        the position capture might not start until half a second or so after 
-        continuous acquisition has. Lastly, the spike times that come out of
-        KiloSort are zero-based as they work from the number of samples saved in
-        the .dat file.
-
-        Zero to the first timestamp of the continuous recording
-        TODO: Could remove data from the continuous recording that happens before the
-        first pos timestamp but leave for now
-
+        Loads the settings.xml data
         '''
-        # self.xyTS = self.xyTS - self.ts[0]
-        # self.ts = self.ts - self.ts[0]
-        self.timeAligned = True
+        if self.settings is None:
+            import os
+            settings = Settings(self.pname_root) # pname_root gets walked through and over-written with correct location of settings.xml
+            settings.parse()
+            settings.parsePos()
+            self.settings = settings
+
+    def __loaddata__(self, **kwargs):
+        self.load(self.pname_root, **kwargs)
 
     def plotXCorrs(self):
         if self.kilodata is None:
             self.loadKilo()
-        from epy.ephys_generic.ephys_generic import SpikeCalcsGeneric
+        from ephysiopy.ephys_generic.ephys_generic import SpikeCalcsGeneric
         corriter = SpikeCalcsGeneric(self.kilodata.spk_times)
         corriter.spk_clusters = self.kilodata.spk_clusters
         corriter.plotAllXCorrs(self.kilodata.good_clusters)
-        # for cluster in corriter:
-            # print("Cluster {0}".format(cluster))
 
-    def plotWaves(self):
-        if self.kilodata is None:
-            self.loadKilo()
-        if self.rawData is None:
-            print("Loading raw data...")
-            self.load(loadraw=True)
-        import os
-        amplitudes = np.load(os.path.join(self.fname_root, 'amplitudes.npy'))
-        waveiter = SpkWaveform(self.kilodata.good_clusters, self.kilodata.spk_times, self.kilodata.spk_clusters, amplitudes, self.rawData)
-        for cluster in waveiter:
-            print("Cluster {}".format(cluster))
-
-    def plotPos(self, jumpmax=None, show=True):
+    def plotPos(self, jumpmax=None, show=True, **kwargs):
         '''
         Plots x vs y position for this trial
 
@@ -246,14 +148,13 @@ class OpenEphysNWB(object):
         if jumpmax is None:
             jumpmax = self.jumpmax
         import matplotlib.pylab as plt
-        from epy.ephys_generic.ephys_generic import PosCalcsGeneric
-        import os
-        settings = Settings(os.path.join(self.fname_root, 'settings.xml'))
-        settings.parsePos()
+        from ephysiopy.ephys_generic.ephys_generic import PosCalcsGeneric
+
+        self.__loadSettings__()
+        if self.xy is None:
+            self.__loaddata__(**kwargs)
         posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], 300, True, jumpmax)
-        settings = Settings(os.path.join(self.fname_root, 'settings.xml'))
-        settings.parsePos()
-        xy, hdir = posProcessor.postprocesspos(settings.tracker_params)
+        xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
         self.hdir = hdir
         if show:
             plt.plot(xy[0], xy[1])
@@ -276,18 +177,17 @@ class OpenEphysNWB(object):
         '''
         if self.kilodata is None:
             self.loadKilo()
-        if self.timeAligned == False:
-            self.__alignTimeStamps__()
         if ( 'ppm' in kwargs.keys() ):
             ppm = kwargs['ppm']
         else:
             ppm = 400
-        from epy.ephys_generic.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
+        from ephysiopy.ephys_generic.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
+        if self.xy is None:
+            self.__loaddata__(**kwargs)
         posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
         import os
-        settings = Settings(os.path.join(self.fname_root, 'settings.xml'))
-        settings.parsePos()
-        xy, hdir = posProcessor.postprocesspos(settings.tracker_params)
+        self.__loadSettings__()
+        xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
         self.hdir = hdir
         spk_times = (self.kilodata.spk_times.T[0] / 3e4) + self.ts[0]
         mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
@@ -312,18 +212,17 @@ class OpenEphysNWB(object):
         '''
         if self.kilodata is None:
             self.loadKilo()
-        if self.timeAligned == False:
-            self.__alignTimeStamps__()
         if ( 'ppm' in kwargs.keys() ):
             ppm = kwargs['ppm']
         else:
             ppm = 400
-        from epy.ephys_generic.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
+        from ephysiopy.ephys_generic.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
+        if self.xy is None:
+            self.__loaddata__(**kwargs)
         posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
         import os
-        settings = Settings(os.path.join(self.fname_root, 'settings.xml'))
-        settings.parsePos()
-        xy, hdir = posProcessor.postprocesspos(settings.tracker_params)
+        self.__loadSettings__()
+        xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
         self.hdir = hdir
         spk_times = (self.kilodata.spk_times.T[0] / 3e4) + self.ts[0]
         mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
@@ -334,7 +233,7 @@ class OpenEphysNWB(object):
         [ print("") for cluster in mapiter ]
 
     def plotEEGPower(self, channel=0):
-        from epy.ephys_generic.ephys_generic import EEGCalcsGeneric
+        from ephysiopy.ephys_generic.ephys_generic import EEGCalcsGeneric
         if self.rawData is None:
             print("Loading raw data...")
             self.load(loadraw=True)
@@ -347,7 +246,7 @@ class OpenEphysNWB(object):
         E.plotPowerSpectrum()
 
     def plotSpectrogram(self, nSeconds=30, secsPerBin=2, ax=None, ymin=0, ymax=250):
-        from epy.ephys_generic.ephys_generic import EEGCalcsGeneric
+        from ephysiopy.ephys_generic.ephys_generic import EEGCalcsGeneric
         if self.rawData is None:
             print("Loading raw data...")
             self.load(loadraw=True)
@@ -358,7 +257,7 @@ class OpenEphysNWB(object):
         from scipy import signal
         freqs, times, Sxx = signal.spectrogram(E.sig, fs, nperseg=nperseg)
         Sxx_sm = Sxx
-        from epy.ephys_generic import binning
+        from ephysiopy.ephys_generic import binning
         R = binning.RateMap()
         Sxx_sm = R.blurImage(Sxx, (secsPerBin*2)+1)
         x, y = np.meshgrid(times, freqs)
@@ -375,13 +274,11 @@ class OpenEphysNWB(object):
 
     def plotPSTH(self):
         import os
-        settings = Settings(os.path.join(self.fname_root, 'settings.xml'))
-        settings.parseStimControl()
+        self.__loadSettings__()
+        self.settings.parseStimControl()
         if self.kilodata is None:
             self.loadKilo()
-        if self.timeAligned == False:
-            self.__alignTimeStamps__()
-        from epy.ephys_generic.ephys_generic import SpikeCalcsGeneric
+        from ephysiopy.ephys_generic.ephys_generic import SpikeCalcsGeneric
         spk_times = (self.kilodata.spk_times.T[0] / 3e4) + self.ts[0] # in seconds
         S = SpikeCalcsGeneric(spk_times)
         S.event_ts = self.ttl_timestamps[2::2] # this is because some of the trials have two weird events logged at about 2-3 minutes in...
@@ -391,7 +288,7 @@ class OpenEphysNWB(object):
             print(next(S.plotPSTH(x)))
 
     def plotEventEEG(self):
-        from epy.ephys_generic.ephys_generic import EEGCalcsGeneric
+        from ephysiopy.ephys_generic.ephys_generic import EEGCalcsGeneric
         if self.rawData is None:
             print("Loading raw data...")
             self.load(loadraw=True)
@@ -399,6 +296,218 @@ class OpenEphysNWB(object):
         event_ts = self.ttl_timestamps[2::2] # this is because some of the trials have two weird events logged at about 2-3 minutes in...
         E.plotEventEEG(event_ts)
 
+    def plotWaves(self):
+        if self.kilodata is None:
+            self.loadKilo()
+        if self.rawData is None:
+            print("Loading raw data...")
+            self.load(loadraw=True)
+        import os
+        amplitudes = np.load(os.path.join(self.fname_root, 'amplitudes.npy'))
+        waveiter = SpkWaveform(self.kilodata.good_clusters, self.kilodata.spk_times, self.kilodata.spk_clusters, amplitudes, self.rawData)
+        for cluster in waveiter:
+            print("Cluster {}".format(cluster))
+
+class OpenEphysNPX(OpenEphysBase):
+    """docstring for OpenEphysNPX"""
+    def __init__(self, pname_root):
+        super().__init__(pname_root)
+
+    def load(self, pname_root: str, experiment_name='experiment1', recording_name='recording1'):
+        '''
+        Loads data recorded in the OE 'flat' binary format
+        See https://open-ephys.atlassian.net/wiki/spaces/OEW/pages/166789121/Flat+binary+format for more
+
+        Parameters
+        ----------
+        pname_root - str - the top level directory that contains the folder 'experiment1'
+        (usually) and settings.xml
+
+        recording_name - str - pretty obvious but this is also the directory immediately beneath pname_root
+        '''
+        import os
+        import re
+        pos_t_match = re.compile('Pos_Tracker-[0-9][0-9][0-9].[0-9]')
+        APdata_match = re.compile('Neuropix-PXI-[0-9][0-9][0-9].0')
+
+        for d, c, f in os.walk(pname_root):
+            for ff in f:
+                if 'data_array.npy' in ff:
+                    path2PosData = os.path.join(d)
+                if 'continuous.dat' in ff:
+                    if APdata_match.search(d):
+                        path2APdata = os.path.join(d)
+
+        pos_data = np.load(os.path.join(path2PosData, 'data_array.npy'))
+        self.xy = pos_data[:,0:2]
+        pos_ts = np.load(os.path.join(path2PosData, 'timestamps.npy'))
+        self.xyTS = pos_ts / 30.0 / 1000.0
+        self.isBinary = True
+
+        sample_rate = 30000
+        n_channels = 384
+        trial_length = self.__calcTrialLengthFromBinarySize__(os.path.join(path2APdata, 'continuous.dat'), n_channels, sample_rate)
+        self.ts = np.arange(0, trial_length, 1.0/sample_rate)
+
+
+    def __calcTrialLengthFromBinarySize__(self, path2file:str, n_channels=384, sample_rate=30000):
+        '''
+        Returns the time taken to run the trial (in seconds) based on the size of
+        the binary file on disk
+        '''
+        import os
+        status = os.stat(path2file)
+        return status.st_size / ( 2.0 * n_channels * sample_rate)
+
+    def plotPos(self, jumpmax=None, show=True):
+        super().plotPos(jumpmax, show)
+
+    def plotMaps(self, plot_type='map', **kwargs):
+        super().plotMaps(plot_type, **kwargs)
+
+    def plotMapsOneAtATime(self, plot_type='map', **kwargs):
+        super().plotMapsOneAtATime(plot_type, **kwargs)
+
+    def plotEEGPower(self, channel=0):
+        super().plotEEGPower(channel)
+
+    def plotSpectrogram(self, nSeconds=30, secsPerBin=2, ax=None, ymin=0, ymax=250):
+        super().plotSpectrogram(self, nSeconds, secsPerBin, ax, ymin, ymax)
+
+    def plotPSTH(self):
+        super().plotPSTH()
+
+    def plotEventEEG(self):
+        super().plotEventEEG()
+
+    def plotWaves(self):
+        super().plotWaves()
+
+class OpenEphysNWB(OpenEphysBase):
+    '''
+    Parameters
+    ------------
+    fname_root:- str
+        Should contain the settings.xml file and the .nwb file
+    '''
+
+    def __init__(self, pname_root, **kwargs):
+        super().__init__(pname_root)
+        self.nwbData = None # handle to the open nwb file (HDF5 file object)
+        self.rawData = None # np.array holding the raw, continuous recording
+        self.recording_name = None # the recording name inside the nwb file ('recording0', 'recording1', etc)
+        self.isBinary = False
+
+    def load(self, pname_root: str, session_name=None, recording_name=None, loadraw=False, loadspikes=False, savedat=False):
+        '''
+        Loads xy pos from binary part of the hdf5 file and data resulting from
+        a Kilosort session (see KiloSortSession class above)
+
+        Parameters
+        ----------
+        pname_root : str
+            The top level directory, typically the one named YYYY-MM-DD_HH-MM-SS
+            NB In the nwb format this directory contains the experiment_1.nwb and settings.xml files
+        session_name : str
+            Defaults to experiment_1.nwb
+        recording_name : str
+            Defaults to recording0
+        loadraw : bool
+            Defaults to False; if True will load and save the
+            raw part of the data
+        savedat : bool
+            Defaults to False; if True will extract the electrode
+            data part of the hdf file and save as 'experiment_1.dat'
+            NB only works if loadraw is True. Also note that this
+            currently saves 64 channels worth of data (ie ignores
+            the 6 accelerometer channels)
+        '''
+
+        import h5py
+        import os
+        if session_name is None:
+            session_name = 'experiment_1.nwb'
+        self.nwbData = h5py.File(os.path.join(pname_root, session_name))
+        # Position data...
+        if self.recording_name is None:
+            if recording_name is None:
+                recording_name = 'recording1'
+            self.recording_name = recording_name
+        self.xy = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['data'])
+
+        self.xyTS = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['binary1']['timestamps'])
+        self.xyTS = self.xyTS - (self.xy[:,2] / 1e6)
+        self.xy = self.xy[:,0:2]
+        # TTL data...
+        self.ttl_data = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['ttl1']['data'])
+        self.ttl_timestamps = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['events']['ttl1']['timestamps'])
+
+        # ...everything else
+        try:
+            self.__loadSettings__()
+            fpgaId = self.settings.fpga_nodeId
+            fpgaNode = 'processor' + str(fpgaId) + '_' + str(fpgaId)
+            self.ts = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['continuous'][fpgaNode]['timestamps'])
+            if (loadraw == True):
+                self.rawData = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['continuous'][fpgaNode]['data'])
+                self.settings.parseChannels() # to get the neural data channels
+                self.accelerometerData = self.rawData[:,64:]
+                self.rawData = self.rawData[:,0:64]
+                if (savedat == True):
+                    data2save = self.rawData[:,0:64]
+                    data2save.tofile(os.path.join(pname_root, 'experiment_1.dat'))
+            if loadspikes == True:
+                if self.nwbData['acquisition']['timeseries'][self.recording_name]['spikes']:
+                    # Create a dictionary containing keys 'electrode1', 'electrode2' etc and None for values
+                    electrode_dict = dict.fromkeys(self.nwbData['acquisition']['timeseries'][self.recording_name]['spikes'].keys())
+                    # Each entry in the electrode dict is itself a dict containing keys 'timestamps' and 'data'...
+                    for i_electrode in electrode_dict.keys():
+                        data_and_ts_dict = {'timestamps': None, 'data': None}
+                        data_and_ts_dict['timestamps'] = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['spikes'][i_electrode]['timestamps'])
+                        data_and_ts_dict['data'] = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['spikes'][i_electrode]['data'])
+                        electrode_dict[i_electrode] = data_and_ts_dict
+                self.spikeData = electrode_dict
+        except:
+            self.ts = self.xy
+
+    def save_ttl(self, out_fname):
+        '''
+        Saves the ttl data to text file out_fname
+        '''
+        if ( len(self.ttl_data) > 0 ) and ( len(self.ttl_timestamps) > 0 ):
+            data = np.array([self.ttl_data, self.ttl_timestamps])
+            if data.shape[0] == 2:
+                data = data.T
+            np.savetxt(out_fname, data, delimiter='\t')
+
+    def exportPos(self):
+        xy = self.plotPos(show=False)
+        out = np.hstack([xy.T, self.xyTS[:,np.newaxis]])
+        np.savetxt('position.txt', out, delimiter=',', fmt=['%3.3i','%3.3i','%3.3f'])
+
+    def plotPos(self, jumpmax=None, show=True):
+        super().plotPos(jumpmax, show)
+
+    def plotMaps(self, plot_type='map', **kwargs):
+        super().plotMaps(plot_type, **kwargs)
+
+    def plotMapsOneAtATime(self, plot_type='map', **kwargs):
+        super().plotMapsOneAtATime(plot_type, **kwargs)
+
+    def plotEEGPower(self, channel=0):
+        super().plotEEGPower(channel)
+
+    def plotSpectrogram(self, nSeconds=30, secsPerBin=2, ax=None, ymin=0, ymax=250):
+        super().plotSpectrogram(self, nSeconds, secsPerBin, ax, ymin, ymax)
+
+    def plotPSTH(self):
+        super().plotPSTH()
+
+    def plotEventEEG(self):
+        super().plotEventEEG()
+
+    def plotWaves(self):
+        super().plotWaves()
 
 class SpkTimeCorrelogram(object):
     def __init__(self, clusters, spk_times, spk_clusters):
